@@ -10,9 +10,11 @@ import logging
 import pkg_resources
 
 from c8connector import (
-    C8Connector, ConfigProperty, Sample, Schema,
+    C8Connector, ConfigProperty, Sample,
     ConfigAttributeType, SchemaAttributeType, SchemaAttribute)
 
+from c8connector import Schema as C8Schema
+
 import singer
 import singer.metrics as metrics
 import singer.schema
@@ -572,7 +574,7 @@ class SnowflakeSourceConnector(C8Connector):
                     t = v['type'][-1]
                     s_attribs.append(SchemaAttribute(
                         k, self.get_attribute_type(t)))
-                schema = Schema(stream.stream, s_attribs)
+                schema = C8Schema(stream.stream, s_attribs)
                 results.append(Sample(
                     schema=schema,
                     data=data)
@@ -582,7 +584,7 @@ class SnowflakeSourceConnector(C8Connector):
         return results
 
     # TODO: Need to add handling of reserved keys
-    def schemas(self, integration: dict) -> list[Schema]:
+    def schemas(self, integration: dict) -> list[C8Schema]:
         """Get supported schemas using the given configurations."""
         config = self.get_config(integration)
         try:
@@ -596,7 +598,7 @@ class SnowflakeSourceConnector(C8Connector):
                     t = v['type'][-1]
                     s_attribs.append(SchemaAttribute(
                         k, self.get_attribute_type(t)))
-                results.append(Schema(stream.stream, s_attribs))
+                results.append(C8Schema(stream.stream, s_attribs))
         except Exception as e:
             raise e
         return results
